package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.SysCity;

/**
 * 城市Service接口
 * 
 * @author haotian
 * @date 2024-11-08
 */
public interface ISysCityService 
{
    /**
     * 查询城市
     * 
     * @param cityId 城市主键
     * @return 城市
     */
    public SysCity selectSysCityByCityId(Long cityId);

    /**
     * 查询城市列表
     * 
     * @param sysCity 城市
     * @return 城市集合
     */
    public List<SysCity> selectSysCityList(SysCity sysCity);

    /**
     * 新增城市
     * 
     * @param sysCity 城市
     * @return 结果
     */
    public int insertSysCity(SysCity sysCity);

    /**
     * 修改城市
     * 
     * @param sysCity 城市
     * @return 结果
     */
    public int updateSysCity(SysCity sysCity);

    /**
     * 批量删除城市
     * 
     * @param cityIds 需要删除的城市主键集合
     * @return 结果
     */
    public int deleteSysCityByCityIds(Long[] cityIds);

    /**
     * 删除城市信息
     * 
     * @param cityId 城市主键
     * @return 结果
     */
    public int deleteSysCityByCityId(Long cityId);
}
